==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip.md <==
# AmazonBraketChip


```text
aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip
```

```text
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')
```



| Illustration | AmazonBraketChip | AmazonBraketChipCard | AmazonBraketChipGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip.png) | ![illustration for AmazonBraketChip](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip.Local.png) | ![illustration for AmazonBraketChipCard](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChipCard.Local.png) | ![illustration for AmazonBraketChipGroup](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChipGroup.Local.png) |




## AmazonBraketChip

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketChip
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')

' renders the element
AmazonBraketChip('AmazonBraketChip', 'Amazon Braket Chip', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketChip
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')

' renders the element
AmazonBraketChip('AmazonBraketChip', 'Amazon Braket Chip', 'an optional tech label')
@enduml
```

## AmazonBraketChipCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketChipCard
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')

' renders the element
AmazonBraketChipCard('AmazonBraketChipCard', 'Amazon Braket Chip Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketChipCard
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')

' renders the element
AmazonBraketChipCard('AmazonBraketChipCard', 'Amazon Braket Chip Card', 'an optional description')
@enduml
```

## AmazonBraketChipGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketChipGroup
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')

' renders the element
AmazonBraketChipGroup('AmazonBraketChipGroup', 'Amazon Braket Chip Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketChipGroup
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')

' renders the element
AmazonBraketChipGroup('AmazonBraketChipGroup', 'Amazon Braket Chip Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip.md <==
# AmazonBraketChip


```text
aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip
```

```text
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')
```



| Illustration | AmazonBraketChip | AmazonBraketChipCard | AmazonBraketChipGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip.png) | ![illustration for AmazonBraketChip](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip.Local.png) | ![illustration for AmazonBraketChipCard](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChipCard.Local.png) | ![illustration for AmazonBraketChipGroup](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChipGroup.Local.png) |




## AmazonBraketChip

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketChip
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')

' renders the element
AmazonBraketChip('AmazonBraketChip', 'Amazon Braket Chip', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketChip
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')

' renders the element
AmazonBraketChip('AmazonBraketChip', 'Amazon Braket Chip', 'an optional tech label')
@enduml
```

## AmazonBraketChipCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketChipCard
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')

' renders the element
AmazonBraketChipCard('AmazonBraketChipCard', 'Amazon Braket Chip Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketChipCard
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')

' renders the element
AmazonBraketChipCard('AmazonBraketChipCard', 'Amazon Braket Chip Card', 'an optional description')
@enduml
```

## AmazonBraketChipGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketChipGroup
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')

' renders the element
AmazonBraketChipGroup('AmazonBraketChipGroup', 'Amazon Braket Chip Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketChipGroup
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketChip')

' renders the element
AmazonBraketChipGroup('AmazonBraketChipGroup', 'Amazon Braket Chip Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
